@@ -1,20 +1,19 @@
 # -*- coding: utf-8 -*-
 
-from zope import schema
-from zope.interface import implements
-
+from collective.documentgenerator import _
+from collective.documentgenerator.utils import compute_md5
 from plone.autoform import directives as form
 from plone.dexterity.content import Item
 from plone.formwidget.namedfile import NamedFileWidget
 from plone.namedfile.field import NamedBlobFile
 from plone.supermodel import model
-
 from Products.CMFPlone.utils import safe_unicode
-
-from collective.documentgenerator import _
-from collective.documentgenerator.utils import compute_md5
+from zope import schema
+from zope.interface import implementer
 
 import logging
+
+
 logger = logging.getLogger('collective.documentgenerator: StyleTemplate')
 
 
@@ -33,13 +32,12 @@ class IStyleTemplate(model.Schema):
     initial_md5 = schema.TextLine(description=u'Initially loaded file md5. Will be compared with os file md5.')
 
 
+@implementer(IStyleTemplate)
 class StyleTemplate(Item):
     """
     StyleTemplate dexterity class.
     """
 
-    implements(IStyleTemplate)
-
     @property
     def current_md5(self):
         md5 = u''
