@@ -1,7 +1,8 @@
 # -*- coding: utf-8 -*-
 """Base module for unittesting."""
 
-from collective.documentgenerator.config import HAS_PLONE_5, HAS_PLONE_5_2
+from collective.documentgenerator.config import HAS_PLONE_5
+from collective.documentgenerator.config import HAS_PLONE_5_2
 from imio.pyutils.system import runCommand
 from plone import api
 from plone.app.robotframework.testing import REMOTE_LIBRARY_BUNDLE_FIXTURE
@@ -17,6 +18,7 @@ from plone.app.testing import TEST_USER_NAME
 from plone.app.testing import TEST_USER_PASSWORD
 from plone.protect.authenticator import createToken
 from plone.testing import z2
+from zope.globalrequest import setLocal
 
 import collective.documentgenerator
 import os
@@ -25,7 +27,6 @@ import transaction
 import unittest
 import zipfile
 
-from zope.globalrequest import setLocal
 
 if HAS_PLONE_5_2:
     import sys
@@ -98,6 +99,7 @@ class DocumentgeneratorLayer(NakedPloneLayer):
 
         # Install into Plone site using portal_setup
         applyProfile(portal, 'collective.documentgenerator:testing')
+        setLocal('request', portal.REQUEST)
 
         # Install plone-content for Plone 4 so front-page is available
         if not HAS_PLONE_5:
