@@ -8,12 +8,12 @@ from collective.documentgenerator.config import HAS_PLONE_5
 from collective.documentgenerator.config import set_column_modifier
 from collective.documentgenerator.content.pod_template import MailingLoopTemplate
 from collective.documentgenerator.content.pod_template import SubTemplate
-from collective.documentgenerator.events.styles_events import create_temporary_file
 from collective.documentgenerator.interfaces import CyclicMergeTemplatesException
 from collective.documentgenerator.interfaces import PODTemplateNotFoundError
 from collective.documentgenerator.testing import POD_TEMPLATE_INTEGRATION
 from collective.documentgenerator.testing import PODTemplateIntegrationTest
 from collective.documentgenerator.testing import TEST_INSTALL_INTEGRATION
+from collective.documentgenerator.utils import create_temporary_file
 from collective.documentgenerator.utils import translate as _
 from plone import api
 from plone.app.testing import login
@@ -224,11 +224,16 @@ class TestGenerationViewMethods(PODTemplateIntegrationTest):
         view(template_uid=pod_template.UID(), output_format='odt')
         hpv = view.get_generation_context_helper()
         # Check context variables
-        self.assertDictEqual(view._get_generation_context(hpv, pod_template), {'details': '1',
-                             'context': hpv.context, 'view': hpv})
+        self.assertDictEqual(view._get_generation_context(hpv, pod_template),
+                             {'details': '1',
+                              'portal': self.portal,
+                              'context': hpv.context,
+                              'view': hpv})
         # Check configurable pod template
         self.assertDictEqual(view._get_generation_context(hpv, self.test_podtemplate),
-                             {'context': hpv.context, 'view': hpv})
+                             {'context': hpv.context,
+                              'portal': self.portal,
+                              'view': hpv})
 
         rendered, filename, gen_context = view._generate_doc(pod_template, 'odt')
 
